class Item:

    def __init__(self, name, days_left, quality):
        self.name = name
        self.days_left = days_left
        self.quality = quality

# After refactoring:
#
# The rules for individual items are clearly separated in special functions.
# Function update() does the same things as before, but
# it has only a single purpose:
# to delegate the processing of individual items to the right specialized functions.
#
# Without tests, the refactoring would be extremely hard to do.
#
# The resulting code is much cleaner. Note:
# * All functions are short.
# * All functions have only a single purpose.
# * None of them contains more than one if statement (only 1 additional indentation level).
# * All lines in all functions are much shorter than 80 characters.


def increase_quality(item):
    if item.quality < 50:
        item.quality += 1


def decrease_quality(item):
    if item.quality > 0:
        item.quality -= 1


def update_brie(item):
    increase_quality(item)
    item.days_left -= 1


def update_tickets(item):
    increase_quality(item)
    if item.days_left < 11:
        increase_quality(item)
    if item.days_left < 6:
        increase_quality(item)
    item.days_left -= 1
    if item.days_left < 0:
        item.quality = 0


def update_diamonds(item):
    pass


def update_normal_item(item):
    decrease_quality(item)
    item.days_left -= 1
    if item.days_left < 0:
        decrease_quality(item)


def update(item):
    if item.name == 'Aged Brie':
        update_brie(item)
    elif item.name == 'Tickets':
        update_tickets(item)
    elif item.name == 'Diamonds':
        update_diamonds(item)
    else:
        update_normal_item(item)